@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2022 The Phosh Developers
+ * Copyright (C) 2022-2024 The Phosh Developers
  *
  * SPDX-License-Identifier: GPL-3-or-later
  *
@@ -34,12 +34,29 @@ test_gm_strv_is_null_or_empty (void)
 }
 
 
+static void
+test_gm_list_devices (void)
+{
+  GStrv devices = gm_list_devices ();
+
+  for (int i = 0; devices[i]; i++)
+    g_message ("Device: '%s'", devices[i]);
+
+  g_assert_true (g_strv_contains ((const char * const *)devices, "purism,librem5"));
+
+  g_strfreev (devices);
+}
+
+
 gint main (gint argc, gchar *argv[])
 {
   g_test_init (&argc, &argv, NULL);
 
+  gm_init ();
+
   g_test_add_func ("/Gm/util/str_null_or_empty", test_gm_str_is_null_or_empty);
   g_test_add_func ("/Gm/util/strv_null_or_empty", test_gm_strv_is_null_or_empty);
+  g_test_add_func ("/Gm/util/list_devices", test_gm_list_devices);
 
   return g_test_run ();
 }
